/*
 * grunt-html-minify
 * https://github.com/yize/grunt-html-minify
 *
 * Copyright (c) 2013 yize
 * Licensed under the MIT license.
 */

'use strict';

module.exports = function (grunt) {

    // Project configuration.
    grunt.initConfig({
        jshint: {
            all: [
                'Gruntfile.js',
                'tasks/*.js',
                '<%= nodeunit.tests %>',
            ],
            options: {
                jshintrc: '.jshintrc',
            },
        },

        // Before generating any new files, remove any previously-created files.
        clean: {
            tests: ['tmp', 'test/fixtures/*.html']
        },

        // Configuration to be run (and then tested).
        html_minify: {
            default_options: {
                options: {
                },
                files: {
                    'test/fixtures/index.html': ['test/ori/index.html']
                }
            },
            gbk: {
                options: {
                    charset:'gbk'
                },
                files: {
                    'test/fixtures/index-gbk.html': ['test/ori/index-gbk.html']
                }
            }
        },

        // Unit tests.
        nodeunit: {
            tests: ['test/*_test.js']
        }

    });

    // Actually load this plugin's task(s).
    grunt.loadTasks('tasks');

    // These plugins provide necessary tasks.
    grunt.loadNpmTasks('grunt-contrib-jshint');
    grunt.loadNpmTasks('grunt-contrib-clean');
    grunt.loadNpmTasks('grunt-contrib-nodeunit');

    // Whenever the "test" task is run, first clean the "tmp" dir, then run this
    // plugin's task(s), then test the result.
    grunt.registerTask('test', ['clean', 'html_minify', 'nodeunit']);

    // By default, lint and run all tests.
    grunt.registerTask('default', ['jshint', 'test']);

};
